@@ -1,5 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -480,20 +481,20 @@ sub AgentQueueListOption {
     my $MoveStr           = $Self->{LanguageObject}->Translate('Move');
     my $ValueOfQueueNoKey = "- " . $MoveStr . " -";
     DATA:
-    for ( sort { $Data{$a} cmp $Data{$b} } keys %Data ) {
+    for my $DataKey ( sort { $Data{$a} cmp $Data{$b} } keys %Data ) {
 
         # find value for default item in select box
         # it can be "-" or "Move"
         if (
-            $Data{$_} eq "-"
-            || $Data{$_} eq $ValueOfQueueNoKey
+            $Data{$DataKey} eq "-"
+            || $Data{$DataKey} eq $ValueOfQueueNoKey
             )
         {
-            $KeyNoQueue   = $_;
-            $ValueNoQueue = $Data{$_};
+            $KeyNoQueue   = $DataKey;
+            $ValueNoQueue = $Data{$DataKey};
             next DATA;
         }
-        $Data{$_} .= '::';
+        $Data{$DataKey} .= '::';
     }
 
     # get HTML utils object
@@ -513,14 +514,14 @@ sub AgentQueueListOption {
 
     # build selection string
     KEY:
-    for ( sort { $Data{$a} cmp $Data{$b} } keys %Data ) {
+    for my $DataKey ( sort { $Data{$a} cmp $Data{$b} } keys %Data ) {
 
         # default item of select box has set already
-        next KEY if ( $Data{$_} eq "-" || $Data{$_} eq $ValueOfQueueNoKey );
+        next KEY if ( $Data{$DataKey} eq "-" || $Data{$DataKey} eq $ValueOfQueueNoKey );
 
-        my @Queue = split( /::/, $Param{Data}->{$_} );
-        $UsedData{ $Param{Data}->{$_} } = 1;
-        my $UpQueue = $Param{Data}->{$_};
+        my @Queue = split( /::/, $Param{Data}->{$DataKey} );
+        $UsedData{ $Param{Data}->{$DataKey} } = 1;
+        my $UpQueue = $Param{Data}->{$DataKey};
         $UpQueue =~ s/^(.*)::.+?$/$1/g;
         if ( !$Queue[$MaxLevel] && $Queue[-1] ne '' ) {
             $Queue[-1] = $Self->Ascii2Html(
@@ -535,8 +536,8 @@ sub AgentQueueListOption {
             # check if SelectedIDRefArray exists
             if ($SelectedIDRefArray) {
                 for my $ID ( @{$SelectedIDRefArray} ) {
-                    if ( $ID eq $_ ) {
-                        $Param{SelectedIDRefArrayOK}->{$_} = 1;
+                    if ( $ID eq $DataKey ) {
+                        $Param{SelectedIDRefArrayOK}->{$DataKey} = 1;
                     }
                 }
             }
@@ -592,13 +593,13 @@ sub AgentQueueListOption {
                 $OptionTitleHTMLValue = ' title="' . $HTMLValue . '"';
             }
             my $HTMLValue = $HTMLUtilsObject->ToHTML(
-                String             => $_,
+                String             => $DataKey,
                 ReplaceDoubleSpace => 0,
             );
             if (
-                $SelectedID eq $_
-                || $Selected eq $Param{Data}->{$_}
-                || $Param{SelectedIDRefArrayOK}->{$_}
+                $SelectedID eq $DataKey
+                || $Selected eq $Param{Data}->{$DataKey}
+                || $Param{SelectedIDRefArrayOK}->{$DataKey}
                 )
             {
                 $Param{MoveQueuesStrg}
@@ -608,7 +609,7 @@ sub AgentQueueListOption {
                     . $String
                     . "</option>\n";
             }
-            elsif ( $CurrentQueueID eq $_ )
+            elsif ( $CurrentQueueID eq $DataKey )
             {
                 $Param{MoveQueuesStrg}
                     .= '<option value="-" disabled="disabled"'
